@@ -45,6 +45,7 @@ class DatLog(models.Model):
     dat_delete = models.DateTimeField(null=True)
 
     class Meta:
+        managed = False
         abstract = True
 
 
@@ -54,6 +55,7 @@ class UsrLog(models.Model):
     usr_delete = models.ForeignKey('usr.Profile', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr_delete')
 
     class Meta:
+        managed = False
         abstract = True
 
 
@@ -64,6 +66,7 @@ class Log(DatLog, UsrLog):
     status = models.BooleanField(null=True, default=True)
 
     class Meta:
+        managed = False
         abstract = True
 
     def save(self, request_=None, *args, **kwargs):
@@ -90,58 +93,61 @@ class Tipo(Log):
     nome = models.CharField(max_length=200, null=True)
     descricao = models.TextField(null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
+        abstract = False
         db_table = 'tipo'
         unique_together = ('codigo', 'tipo')
-        managed = False
+
 
 
 class Empresa(Log):
     nome = models.CharField(max_length=100, null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
+        abstract = False
         db_table = 'empresa'
-        managed = False
 
 
 class EmpresaLog(models.Model):
     empresa = models.ForeignKey(Empresa, on_delete=models.DO_NOTHING, null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
         abstract = True
 
 
-class Sistema(Log):
-    nome = models.CharField(max_length=100, primary_key=True)
+class Modulo(Log):
+    nome = models.SlugField(max_length=100, primary_key=True)
     nm_descritivo = models.CharField(max_length=200, null=True)
+    modulo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
 
-    class Meta:
-        db_table = 'sistema'
-        managed = False
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'modulo'
 
 
 class Versao(Log):
-    sistema = models.ForeignKey(Sistema, null=True, on_delete=models.DO_NOTHING)
+    modulo = models.ForeignKey('core.Modulo', null=True, on_delete=models.DO_NOTHING)
     responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
     dat_atualizacao = models.DateField(null=True)
     codigo = models.CharField(max_length=100, null=True)
     commit = models.CharField(max_length=50, null=True)
     descricao = models.TextField(null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
+        abstract = False
         db_table = 'versao'
-        managed = False
+
 
 
 class VersaoItem(Log):
-    versao = models.ForeignKey(Versao, null=True, on_delete=models.DO_NOTHING)
+    versao = models.ForeignKey('core.Versao', null=True, on_delete=models.DO_NOTHING)
     responsavel = models.ForeignKey('usr.Profile', null=True, on_delete=models.DO_NOTHING)
     ordem = models.IntegerField(null=True)
     descricao = models.TextField(null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
+        abstract = False
         db_table = 'versaoitem'
-        managed = False
 
 
 class Erro(Log):
@@ -149,6 +155,83 @@ class Erro(Log):
     codigo = models.CharField(max_length=200, null=True)
     descricao = models.TextField(null=True)
 
-    class Meta:
+    class Meta(Log.Meta):
+        abstract = False
         db_table = 'erro'
-        managed = False
\ No newline at end of file
+
+
+class UF(Log):
+    codigo = models.IntegerField(primary_key=True)
+    nome = models.CharField(max_length=200, null=True)
+    nm_abrev = models.CharField(max_length=2, null=True)
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'uf'
+
+
+class Municipio(Log):
+    uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
+    codigo = models.IntegerField(primary_key=True)
+    nome = models.CharField(max_length=200)
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'municipio'
+
+
+class Data(Log):
+    anomesdia = models.IntegerField(primary_key=True)
+    anomes = models.IntegerField(null=True)
+    ano = models.IntegerField(null=True)
+
+    dat_dia = models.DateTimeField(null=True)
+
+    nr_mes = models.IntegerField(null=True)
+    ds_mes = models.CharField(max_length=50, null=True)
+    ds_mes_abreviado = models.CharField(max_length=3, null=True)
+
+    nr_dia = models.IntegerField(null=True)
+    ds_dia_semana = models.CharField(max_length=50, null=True)
+
+    nr_semana_ano = models.IntegerField(null=True)
+    ds_semana_ano = models.CharField(max_length=50, null=True)
+
+    nr_semana_mes = models.IntegerField(null=True)
+    ds_semana_mes = models.CharField(max_length=50, null=True)
+
+    nr_bimestre_ano = models.IntegerField(null=True)
+    ds_bimestre_ano = models.CharField(max_length=50, null=True)
+
+    nr_trimestre_ano = models.IntegerField(null=True)
+    ds_trimestre_ano = models.CharField(max_length=50, null=True)
+
+    nr_quadrimestre_ano = models.IntegerField(null=True)
+    ds_quadrimestre_ano = models.CharField(max_length=50, null=True)
+
+    nr_semestre_ano = models.IntegerField(null=True)
+    ds_semestre_ano = models.CharField(max_length=50, null=True)
+
+    nr_primeiro_dia_anomes = models.IntegerField(null=True)
+
+    is_ultimo_dia_mes = models.BooleanField(null=True)
+    ds_feriado_nacional = models.CharField(max_length=200, null=True)
+
+    class Meta(Log.Meta):
+        abstract = False
+        db_table = 'data'
+
+
+class Endereco(Log):
+    cep = models.CharField(max_length=10, null=True)
+    municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
+    bairro = models.CharField(max_length=100, null=True)
+    rua = models.CharField(max_length=100, null=True)
+    numero = models.CharField(max_length=30, null=True)
+    complemento = models.CharField(max_length=100, null=True)
+    ponto_referencia = models.CharField(max_length=100, null=True)
+    latitude = models.CharField(max_length=200, null=True)
+    longitude = models.CharField(max_length=200, null=True)
+
+    class Meta(Log.Meta):
+        abstract = True
